<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:import href="oxygen_custom.xsl"/>
    <!-- There can be SVG inside the imageobject. Let apply templates in this case. -->
    <xsl:template match="d:imageobject" xmlns:d="http://docbook.org/ns/docbook" xmlns:svg="http://www.w3.org/2000/svg">
        <xsl:choose>
            <xsl:when test="d:imagedata">
                <xsl:apply-templates select="d:imagedata"/>
            </xsl:when>
            <xsl:when test="svg:*">
                <xsl:copy-of select="svg:*"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="d:itemizedlist" xmlns:d="http://docbook.org/ns/docbook" xmlns:svg="http://www.w3.org/2000/svg">
        <!-- Handle spacing="compact" as multiple class attribute instead
       of the deprecated HTML compact attribute -->
        <xsl:variable name="default.class">
            <xsl:value-of select="local-name()"/>
            <xsl:if test="@spacing = 'compact'">
                <xsl:text> compact</xsl:text>
            </xsl:if>
        </xsl:variable>
        <xsl:variable name="style.value"></xsl:variable>
        <div>
            <xsl:call-template name="common.html.attributes"/>
            <xsl:call-template name="id.attribute"/>
            <xsl:call-template name="anchor"/>
            <xsl:if test="d:title|d:info/d:title">
                <xsl:call-template name="formal.object.heading"/>
            </xsl:if>
            
            <!-- Preserve order of PIs and comments -->
            <xsl:apply-templates select="*[not(self::d:listitem                   or self::d:title                   or self::d:titleabbrev)]                 |comment()[not(preceding-sibling::d:listitem)]                 |processing-instruction()[not(preceding-sibling::d:listitem)]"/>
            
            <ul>
                <xsl:call-template name="generate.class.attribute">
                    <xsl:with-param name="class" select="$default.class"/>
                </xsl:call-template>
                <xsl:choose>
                    <xsl:when test="$css.decoration != 0">
                        <xsl:attribute name="style">
                            <xsl:value-of select="$style.value"/>
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:when test="$make.clean.html != 0">
                        <!-- styled by separate css only -->
                    </xsl:when>
                    <xsl:otherwise>
                        <!-- use the old @type attribute -->
                        <xsl:attribute name="type">
                            <xsl:call-template name="list.itemsymbol"/>
                        </xsl:attribute>
                    </xsl:otherwise>
                </xsl:choose>
                
                <xsl:apply-templates select="d:listitem                     |comment()[preceding-sibling::d:listitem]                     |processing-instruction()[preceding-sibling::d:listitem]"/>
            </ul>
        </div>
    </xsl:template>
    
</xsl:stylesheet>
